Liefermethoden
==============

Stammdaten
----------

Name
   Eindeutiger Name der Liefermethode. Dieser wird auf der Checkout-Seite zur 
   Auswahl der Liefermethode angezeigt, beispielsweise auf der Checkout-Seite.

Beschreibung
   Kurze Beschreibung der Liefermethode für interne Zwecke.

Notiz
   Diese Notiz wird auf der Dankesseite und der Bestellungen angezeigt.

Priorität
   Bestimmt die Reihenfolge der Anzeige aller Liefermethoden.
   
Bild
   Wird auf der Checkout-Seite neben dem Titel angzeigt.

Aktiv
   Selektieren um die die Liefermethode aktivieren. Nur aktive Liefermethoden 
   werden Shopkunden zur Auswahl angeboten.

Mehrwertsteuer
   Der Mehrwertsteuersatz der Liefermethode.

Preis
   Der Standardpreis der Liefermethode. Dieser ist aktiv, wenn entweder keine
   weiteren Preise angegeben sind, bzw. kein weiterer Preis gültig ist, siehe
   Preise-Tab.
   
Lieferzeit
   Die Lieferzeit der Liefermethode.

Kriterien
---------
Kriterien der Liefermethode. Nur wenn alle Kriterien gültig sind, wird die 
Liefermethode Shopkunden zur Auswahl angeboten.

Preise
------
Zusätzliche Preise für die Liefermethode. 

Beispielsweise kann der Preis abhängig vom Gesamtgewicht aller Produkte im 
Warenkorb gemacht werden. Der erste Preis, der gültig ist, d.h. für den alle 
Kriterien zutreffen, ist der aktive Preis. Wenn kein Preis gültig ist, gilt der
Standardpreis des Daten-Tabs.